library(easyNCDF)

save_ensemble_file <-
  function(variable,
           calibrated_fcst,
           fcst.sdate,
           lon,
           lat,
           outfile,
           monthnames,
           fcst.type = 'seasonal') {

    ## TODO: reorder calibrated values array (if needed)
    calibrated_fcst <- aperm(calibrated_fcst, c(3, 4, 1, 2))
    names(dim(calibrated_fcst)) <- c('latitude', 'longitude','ensemble', 'time')
    
    if (variable == "prlr") { 
      units = c('mm')
      variable.longname = 'Total precipitation' 
      if (fcst.type == 'seasonal'){
        for (month in 1:length(monthnames)){
          
          month.sdate <- paste0(substr(monthnames[month],1,7), "-01")
          month.lastday <- as.integer(substr((seq(as.Date(month.sdate, "%Y-%m-%d"),
                           length=2,by="months")-1)[2], 9, 10))
          calibrated_fcst[,,,month] <- calibrated_fcst[,,,month]*month.lastday*86400000      
        }
      } else {
        calibrated_fcst <- calibrated_fcst * 1000 * 3600 * 24 * 7      
      }
    } else if (variable == "tasmin") {
      units = c('ºC')
      variable.longname = 'Minimum daily surface temperature' 
      calibrated_fcst <- calibrated_fcst - 273
    } else if (variable == "tasmax") {
      units = c('ºC')
      variable.longname = 'Maximum daily surface temperature' 
      calibrated_fcst <- calibrated_fcst - 273
    } else if (variable == "tas") {
      units = c('ºC')
      variable.longname = 'Minimum daily temperature' 
      calibrated_fcst <- calibrated_fcst - 273
    } else if (variable == "sfcWind") {
      units = c('m/s')
      variable.longname = 'Surface Wind Speed' 
    } else if (variable == "rsds") {
      units = c('W/m2')
      variable.longname = 'Short wave solar radiation downwards' 
    } else if (variable == "psl") {
      units = c('Pa')
      variable.longname = 'Mean sea level pressure' 
      calibrated_fcst <- calibrated_fcst / 100
    } else {
      units = c('')
      variable.longname = '' 
    }

    metadata <- list(var = 
        list(
            name = variable,
            standard_name = variable.longname,
            units = units
        )
    )
    
    attr(calibrated_fcst, 'variables') <- metadata
    
    if (fcst.type == 'seasonal') {
      time <- 1:3
      dim(time) <- length(time)
      metadata <-
        list(time = list(
          standard_name = paste(
            monthnames[1],
            ', ',
            monthnames[2]
            ,
            ', ',
            monthnames[3],
            sep = ''
          ),
          units = paste0('months since ', fcst.sdate, ' 00:00:00')
        ))
      attr(time, 'variables') <- metadata
      names(dim(time)) <- 'time'
    } else {
      time <- 1:4
      dim(time) <- length(time)
      metadata <-
        list(time = list(
          units = paste0('weeks since ', paste(substr(fcst.sdate,1,4),substr(fcst.sdate,5,6),substr(fcst.sdate,7,8), sep='-'), ' 00:00:00')
        ))
      attr(time, 'variables') <- metadata
      names(dim(time)) <- 'time'
    }

    
    longitude <- lon
    dim(longitude) <- length(longitude)
    metadata <- list(longitude = list(units = 'degrees_east'))
    attr(longitude, 'variables') <- metadata
    names(dim(longitude)) <- 'longitude'
    
    latitude <- lat
    dim(latitude) <- length(latitude)
    metadata <- list(latitude = list(units = 'degrees_north'))
    attr(latitude, 'variables') <- metadata
    names(dim(latitude)) <- 'latitude'

  #  attrs <- list(global_attrs = list(
  #    model_name = system.name,
  #    computational_time = paste0('months since ', sdates.names, ' 00:00:00')
  #  ))
  #  attributes(latitude) <- c(attributes(latitude), attrs)
  #  
    
    if (fcst.type == 'seasonal') {
      time_step <- 1
      dim(time_step) <- length(time_step)
      metadata <-
        list(time_step = list(unitss = paste0(
          'months since ', fcst.sdate, ' 00:00:00'
        )))
      attr(time_step, 'variables') <- metadata
      names(dim(time_step)) <- 'Time step'
    } else {
      time_step <- 1
      dim(time_step) <- length(time_step)
      metadata <-
        list(time_step = list(unitss = paste0(
          'months since ', fcst.sdate, ' 00:00:00'
        )))
      attr(time_step, 'variables') <- metadata
      names(dim(time_step)) <- 'time_step'
      
    }

    ArrayToNc(
      list(
        latitude,
        longitude,
        time,
        time_step,
        calibrated_fcst
      ),
     outfile
    )
 
 }

save_probs_file <-
  function(variable,
           tercile_probs,
           extreme_probs,
           fcst.sdate,
           lon,
           lat,
           outfile,
           monthnames,
           fcst.type = 'seasonal') {

    prob_bn <- aperm(tercile_probs[1, , ,], c(2, 3, 1))
    prob_n <- aperm(tercile_probs[2, , ,], c(2, 3, 1))
    prob_an <- aperm(tercile_probs[3, , ,], c(2, 3, 1))
    prob_bp10 <- aperm(extreme_probs[1, , ,], c(2, 3, 1))
    prob_ap90 <- aperm(extreme_probs[3, , ,], c(2, 3, 1))

    metadata <- list(
      prob_bn = list(
        name = 'prob_bn',
        standard_name = paste(
          'Probability below normal category', sep = '')
      ),
      prob_n = list(
        name = 'prob_n',
        standard_name = paste('Probability normal category', sep ='')
      ),
      prob_an = list(
        name = 'prob_an',
        standard_name = paste(
          'Probability above normal category', sep = '')
      ),
      prob_bp10 = list(
        name = 'prob_bp10',
        standard_name = paste(
          'Probability below extreme category', sep = '')
      ),
      prob_ap90 = list(
        name = 'prob_ap90',
        standard_name = paste(
          'Probability above extreme category', sep = '')
      ))

    attr(prob_bn, 'variables') <- metadata[1]
    attr(prob_n, 'variables') <- metadata[2]
    attr(prob_an, 'variables') <- metadata[3]
    attr(prob_bp10, 'variables') <- metadata[4]
    attr(prob_ap90, 'variables') <- metadata[5]

    names(dim(prob_bn)) <- c('latitude', 'longitude', 'time')
    names(dim(prob_n)) <- c('latitude', 'longitude', 'time')
    names(dim(prob_an)) <- c('latitude', 'longitude', 'time')
    names(dim(prob_bp10)) <- c('latitude', 'longitude', 'time')
    names(dim(prob_ap90)) <- c('latitude', 'longitude', 'time')
 
    if (fcst.type == 'seasonal') {
      time <- 1:3
      dim(time) <- length(time)
      metadata <-
        list(time = list(
          standard_name = paste(
            monthnames[1],
            ', ',
            monthnames[2]
            ,
            ', ',
            monthnames[3],
            sep = ''
          ),
          units = paste0('months since ', fcst.sdate, ' 00:00:00')
        ))
      attr(time, 'variables') <- metadata
      names(dim(time)) <- 'time'
    } else {
      time <- 1:4
      dim(time) <- length(time)
      metadata <-
        list(time = list(
          units = paste0('weeks since ', paste(substr(fcst.sdate,1,4),substr(fcst.sdate,5,6),substr(fcst.sdate,7,8), sep='-'), ' 00:00:00')
        ))
      attr(time, 'variables') <- metadata
      names(dim(time)) <- 'time'
    }

    
    longitude <- lon
    dim(longitude) <- length(longitude)
    metadata <- list(longitude = list(units = 'degrees_east'))
    attr(longitude, 'variables') <- metadata
    names(dim(longitude)) <- 'longitude'
    
    latitude <- lat
    dim(latitude) <- length(latitude)
    metadata <- list(latitude = list(units = 'degrees_north'))
    attr(latitude, 'variables') <- metadata
    names(dim(latitude)) <- 'latitude'

  #  attrs <- list(global_attrs = list(
  #    model_name = system.name,
  #    computational_time = paste0('months since ', sdates.names, ' 00:00:00')
  #  ))
  #  attributes(latitude) <- c(attributes(latitude), attrs)
  #  
    
    if (fcst.type == 'seasonal') {
      time_step <- 1
      dim(time_step) <- length(time_step)
      metadata <-
        list(time_step = list(unitss = paste0(
          'months since ', fcst.sdate, ' 00:00:00'
        )))
      attr(time_step, 'variables') <- metadata
      names(dim(time_step)) <- 'Time step'
    } else {
      time_step <- 1
      dim(time_step) <- length(time_step)
      metadata <-
        list(time_step = list(unitss = paste0(
          'months since ', fcst.sdate, ' 00:00:00'
        )))
      attr(time_step, 'variables') <- metadata
      names(dim(time_step)) <- 'time_step'
      
    }
    ArrayToNc(
      list(
        latitude,
        longitude, time, time_step,
        prob_bn,
        prob_n,
        prob_an,
        prob_bp10,
        prob_ap90
      ),
     outfile
    )
 
 }

save_skill_file <-
  function(variable,
           fRPSS,
           BSS10,
           BSS90,
           fcst.sdate,
           lon,
           lat,
           outfile,
           monthnames,
           fcst.type = 'seasonal') {

    rpss <- aperm(fRPSS[ , ,], c(2, 3, 1))
    bsp10 <- aperm(BSS10[ , ,], c(2, 3, 1))
    bsp90 <- aperm(BSS90[ , ,], c(2, 3, 1))

    metadata <- list(
      rpss = list(
        name = 'rpss',
        standard_name = paste(
          'Terciles skill score', sep = '')
      ),
      bsp10 = list(
        name = 'bsp10',
        standard_name = paste('Lower extreme tercile skill score', sep ='')
      ),
      bsp90 = list(
        name = 'bsp90',
        standard_name = paste(
          'Upper extreme tercile skill score', sep = '')
      ))

    attr(rpss, 'variables') <- metadata[1]
    attr(bsp10, 'variables') <- metadata[2]
    attr(bsp90, 'variables') <- metadata[3]

    names(dim(rpss)) <- c('latitude', 'longitude', 'time')
    names(dim(bsp10)) <- c('latitude', 'longitude', 'time')
    names(dim(bsp90)) <- c('latitude', 'longitude', 'time')
 
    if (fcst.type == 'seasonal') {
      time <- 1:3
      dim(time) <- length(time)
      metadata <-
        list(time = list(
          standard_name = paste(
            monthnames[1],
            ', ',
            monthnames[2]
            ,
            ', ',
            monthnames[3],
            sep = ''
          ),
          units = paste0('months since ', fcst.sdate, ' 00:00:00')
        ))
      attr(time, 'variables') <- metadata
      names(dim(time)) <- 'time'
    } else {
      time <- 1:4
      dim(time) <- length(time)
      metadata <-
        list(time = list(
          units = paste0('weeks since ', paste(substr(fcst.sdate,1,4),substr(fcst.sdate,5,6),substr(fcst.sdate,7,8), sep='-'), ' 00:00:00')
        ))
      attr(time, 'variables') <- metadata
      names(dim(time)) <- 'time'
    }
    longitude <- lon
    dim(longitude) <- length(longitude)
    metadata <- list(longitude = list(units = 'degrees_east'))
    attr(longitude, 'variables') <- metadata
    names(dim(longitude)) <- 'longitude'
    
    latitude <- lat
    dim(latitude) <- length(latitude)
    metadata <- list(latitude = list(units = 'degrees_north'))
    attr(latitude, 'variables') <- metadata
    names(dim(latitude)) <- 'latitude'

    if (fcst.type == 'seasonal') {
      time_step <- 1
      dim(time_step) <- length(time_step)
      metadata <-
        list(time_step = list(unitss = paste0(
          'months since ', fcst.sdate, ' 00:00:00'
        )))
      attr(time_step, 'variables') <- metadata
      names(dim(time_step)) <- 'Time step'
    } else {
      time_step <- 1
      dim(time_step) <- length(time_step)
      metadata <-
        list(time_step = list(unitss = paste0(
          'weeks since ', fcst.sdate, ' 00:00:00'
        )))
      attr(time_step, 'variables') <- metadata
      names(dim(time_step)) <- 'time_step'
      
    }
    ArrayToNc(
      list(
        latitude,
        longitude,
        time,
        time_step,
        rpss,
        bsp10,
        bsp90
      ),
     outfile
    )
 
 }


save_terciles_file <-

  function(variable,
           terciles_hcst,
           extremes_hcst,
           fcst.sdate,
           lon,
           lat,
           outfile,
           monthnames,
           fcst.type = 'seasonal') {

    p33 <- aperm(terciles_hcst[1, , ,], c(2, 3, 1))
    p66 <- aperm(terciles_hcst[2, , ,], c(2, 3, 1))
    p10 <- aperm(extremes_hcst[1, , ,], c(2, 3, 1))
    p90 <- aperm(extremes_hcst[2, , ,], c(2, 3, 1))
 
    # TODO: CHANGE HARDCODE MONTH LENGTH

    if (variable == "prlr") {
      if (fcst.type == 'seasonal'){
        for (month in 1:(dim(p33)[3])){

          month.sdate <- paste0(substr(monthnames[month],1,7), "-01")
          month.lastday <- as.integer(substr((seq(as.Date(month.sdate, "%Y-%m-%d"),
                           length=2,by="months")-1)[2], 9, 10))
          print(month.lastday)
          p33[,,month] <- p33[,,month]*month.lastday*86400000
          p66[,,month] <- p66[,,month]*month.lastday*86400000
          p90[,,month] <- p90[,,month]*month.lastday*86400000
          p10[,,month] <- p10[,,month]*month.lastday*86400000
        }
      } else {
        p33 <- p33 * 1000 * 3600 * 24 * 7
        p66 <- p66 * 1000 * 3600 * 24 * 7
        p90 <- p90 * 1000 * 3600 * 24 * 7
        p10 <- p10 * 1000 * 3600 * 24 * 7
      }
    } else if (variable == "tasmin" || variable == "tasmax" || variable == "tas") {
      p33 <- p33 - 273
      p66 <- p66 - 273
      p10 <- p10 - 273
      p90 <- p90 - 273
    } else if (variable == "psl") {
      p33 <- p33 / 100
      p66 <- p66 / 100
      p10 <- p10 / 100
      p90 <- p90 / 100
    } else {
      warning("NO UNITS CONVERSION")
    }


    metadata <- list(
      p33 = list(
        name = 'p33',
        standard_name = paste(
          'Lower tercile', sep = '')
      ),
      p66 = list(
        name = 'p66',
        standard_name = paste('Upper tercile', sep ='')
      ),
      p10 = list(
        name = 'p10',
        standard_name = paste(
          'Lower extreme tercile', sep = '')
      ),
      p90 = list(
        name = 'p90',
        standard_name = paste(
          'Upper extreme tercile', sep = '')
      ))

    attr(p33, 'variables') <- metadata[1]
    attr(p66, 'variables') <- metadata[2]
    attr(p10, 'variables') <- metadata[3]
    attr(p90, 'variables') <- metadata[4]

    names(dim(p33)) <- c('latitude', 'longitude', 'time')
    names(dim(p66)) <- c('latitude', 'longitude', 'time')
    names(dim(p10)) <- c('latitude', 'longitude', 'time')
    names(dim(p90)) <- c('latitude', 'longitude', 'time')
 
    if (fcst.type == 'seasonal') {
      time <- 1:3
      dim(time) <- length(time)
      metadata <-
        list(time = list(
          standard_name = paste(
            monthnames[1],
            ', ',
            monthnames[2]
            ,
            ', ',
            monthnames[3],
            sep = ''
          ),
          units = paste0('months since ', fcst.sdate, ' 00:00:00')
        ))
      attr(time, 'variables') <- metadata
      names(dim(time)) <- 'time'
    } else {
      time <- 1:4
      dim(time) <- length(time)
      metadata <-
        list(time = list(
          units = paste0('weeks since ', paste(substr(fcst.sdate,1,4),substr(fcst.sdate,5,6),substr(fcst.sdate,7,8), sep='-'), ' 00:00:00')
        ))
      attr(time, 'variables') <- metadata
      names(dim(time)) <- 'time'
     
    }
    
    longitude <- lon
    dim(longitude) <- length(longitude)
    metadata <- list(longitude = list(units = 'degrees_east'))
    attr(longitude, 'variables') <- metadata
    names(dim(longitude)) <- 'longitude'
    
    latitude <- lat
    dim(latitude) <- length(latitude)
    metadata <- list(latitude = list(units = 'degrees_north'))
    attr(latitude, 'variables') <- metadata
    names(dim(latitude)) <- 'latitude'
    
    if (fcst.type == 'seasonal') {
      time_step <- 1
      dim(time_step) <- length(time_step)
      metadata <-
        list(time_step = list(unitss = paste0(
          'months since ', fcst.sdate, ' 00:00:00'
        )))
      attr(time_step, 'variables') <- metadata
      names(dim(time_step)) <- 'Time step'
    } else {
      time_step <- 1
      dim(time_step) <- length(time_step)
      metadata <-
        list(time_step = list(unitss = paste0(
          'weeks since ', fcst.sdate, ' 00:00:00'
        )))
      attr(time_step, 'variables') <- metadata
      names(dim(time_step)) <- 'time_step'
      
    }
    ArrayToNc(
      list(
        latitude,
        longitude,
        time,
        time_step,
        p33,
        p66,
        p10,
        p90
      ),
     outfile
    )
 
 }
