s2s4e.global <-
  function(variable = NULL,
           fcst.sdate = NULL,
           skill = FALSE,
           country = TRUE,
           global = TRUE,
           path.outside = NULL) {

    # variable  <- climate variable. Select between: tas, tasmax, tasmin, prlr, rsds, sfcWind or psl.
    # fcst.sdate <- Date of the forecast startdate (YYYYMM01), example: 20180201 
    # skill  <- TRUE if the skill and terciles computation is needed. FALSE if the the skill has 
    #	        been already computed and exported in it's correct format. 
    # country  <- TRUE if country-aggregated data has to be computed according to the provided
    #              mask	defining the countries 
    # global <- TRUE if the global grid computation has to be executed. FALSE if not. 
    # path.outside <- Path where should be save the ncdf file
    #                 ej. "/esarchive/oper/S2S4E-data/monthly_data/tas/"
    #                 If terciles are loaded from .nc, the script will try to find them in this dir.

    #-------------------------------------------------------------------
    # Libraries & functions load
    #-------------------------------------------------------------------

    cat("Variable:   "); print(variable)
    cat("Sdate: "); print(fcst.sdate)
    cat("Skill: "); print(skill)
    cat("Country: "); print(country)
    cat("GLOBAL: "); print(global)
    cat("Outpath: "); print(path.outside)

    library(s2dverification)
    library(multiApply)
    library(startR)

    library(CSTools)
    Hcst_Calibration <- CSTools:::Calibration
    .cal <- CSTools:::.cal

    source("create_nc.R")  # Load function to export results to .nc 
    source("create_nc_country.R") # Same for country data 
    source("Calibration_fcst.R")
    source("s2s4e_tools.R")

    #-------------------------------------------------------------------
    # Settings 
    #-------------------------------------------------------------------
 
    system.name <- "system5"
    exp.dir <- "/esarchive/exp/ecmwf/system5c3s/" 
    obs.dir <- "/esarchive/recon/ecmwf/era5/"   
    hcst.inityear <- 1993 
    hcst.endyear <- 2017

    remap.method <- "con" 

    ncores=8
    split_factor=1

    lons.min <- 0  #0
    lons.max <- 360  #360
    lats.min <- -90  #-90
    lats.max <- 90 # 90
    
    hcst.nmember <- 25 # Number of members of the ensemble for the hcst,
                       # for the fcst all the ensemble available is used.

    ltmin <- 2
    fcst.freq <- "monthly_mean"
    ltmax <- 4

    mask.path <- '/esarchive/oper/S2S4E-backend-BSC/data-analysis/masks/mask_europe_system5_2.Rdata'

    #-------------------------------------------------------------------
    # Init (This part is highly dependent on the srcdir structure) 
    #-------------------------------------------------------------------
    
    # variables and freq

    exp.6hourly <- c('tas', 'sfcwind', 'psl')
    exp.24hourly <- c('tasmax', 'tasmin', 'prlr', 'rsds')
    obs.24hourly <- c('prlr', 'rsds', 'tasmax', 'tasmin')
    obs.1hourly <- c('sfcwind', 'psl', 'tas')
    
    accum.vars <- c('prlr', 'rsds')

    if (tolower(variable) %in% obs.1hourly){
      freq.obs <- 'f1h'
    }
    if (tolower(variable) %in% obs.24hourly){
      if(tolower(variable) %in% accum.vars){
        freq.obs <- 's0-24h'
      } else {
        freq.obs <- 'f24h'
      }
    }

    if (tolower(variable) %in% exp.6hourly){
      freq.exp <- 'f6h'
    }
    if (tolower(variable) %in% exp.24hourly){
      if(tolower(variable) %in% accum.vars){
        freq.exp <- 's0-24h'
      } else {
        freq.exp <- 'f24h'
      }
    }
    
    # Start dates and Lead times

    fcst.month <- substr(fcst.sdate,5,6) 
    fcst.year <- substr(fcst.sdate,1,4) 

    fcst.sdate <- paste(fcst.year, fcst.month, sep = "")
    hcst.sdates <- paste(strtoi(hcst.inityear):strtoi(hcst.endyear),
                         fcst.month, sep = "")

    obs.sdates <- hcst.sdates

    #-------------------------------------------------------------------
    # Timeseries load 
    #-------------------------------------------------------------------
    obs.path <- paste0(
          obs.dir,fcst.freq,
          "/$var$_",
          freq.obs,
          "/$var$_$file_date$.nc"
        )

    fcst.path <- paste0( exp.dir,fcst.freq, "/$var$_", freq.exp,
               "/$var$_$sdate$01.nc"
        )

    hcst.path <- paste0(
               exp.dir,fcst.freq,
               "/$var$_",
               freq.exp,
               "/$var$_$sdate$01.nc"
        )

    hcst<-Start(dat = hcst.path,
              var = variable,
              sdate = hcst.sdates,
              time = indices(ltmin:ltmax),
              latitude = values(list(lats.min, lats.max)),
              longitude = values(list(lons.min, lons.max)),
              synonims = list(latitude=c('lat','latitude'),
                              longitude=c('lon','longitude'),
			      member='ensemble'), 
              member = indices(1:hcst.nmember),
              return_vars = list(latitude = 'dat',
                                 longitude = 'dat',
                                 time = c('sdate')),
              retrieve = T)
     
    fcst <- Start(dat = fcst.path,
              var = variable,
              sdate = fcst.sdate,
              time = indices(ltmin:ltmax),
              latitude = values(list(lats.min, lats.max)),
              longitude = values(list(lons.min, lons.max)),
              synonims = list(latitude=c('lat','latitude'),
                              longitude=c('lon','longitude'),
			      member='ensemble'), 
              member = 'all',
              return_vars = list(latitude = 'dat',
                                 longitude = 'dat',
                                 time = c('sdate')),
              retrieve = T)

    dates <- attr(hcst, 'Variables')$common$time
    dates_file <- sapply(dates, format, '%Y%m')
    dim(dates_file) <- dim(dates)

    obs <- Start(dat = obs.path,		  
                  var = variable,
		  file_date = dates_file,
		  latitude = values(list(lats.min, lats.max)),
		  longitude = values(list(lons.min, lons.max)),
                  synonims = list(latitude=c('lat','latitude'),
                                  longitude=c('lon','longitude')), 
		  transform = CDORemapper,
		  transform_params = list(
		    grid = paste0(
		      exp.dir,fcst.freq,
		      "/",variable,"_",
		      freq.exp,
		      "/",variable,"_",fcst.sdate,"01.nc"
		      ),
		    method = 'con',
		    crop = c(lons.min,lons.max,lats.min,lats.max)
		  ), 
		  transform_vars = c('latitude', 'longitude'), 
		  return_vars = list(latitude = 'dat',
                                     longitude = 'dat',
                                     time = 'file_date'),
		  split_multiselected_dims = TRUE,
		  retrieve = TRUE)

    print("######### DATA LOADING COMPLETED ##############")
    
    lon <- attr(obs, 'Variables')$dat1$longitude
    lat <- attr(obs, 'Variables')$dat1$latitude
    hcst.times <- attr(hcst, 'Variables')$common$time
    hcst.times <- sort(unique(sapply(as.character(hcst.times),
                      substr, 1, 10)))
    hcst.times[which(substr(hcst.times, 9, 10) == '01')] <- as.character(as.Date(hcst.times[which(substr(hcst.times, 9, 10) == '01')], "%Y-%m-%d")-1)


    #-------------------------------------------------------------------
    # Forecast Bias adjustment (calibration method)
    #-------------------------------------------------------------------

    default_dims <- c(dat=1, var=1, sdate = 1, time=1, latitude=1, longitude=1, member = 1)
    default_dims[names(dim(obs))] <- dim(obs)
    dim(obs) <- default_dims

    sub_obs<-Subset(obs,c('dat','var'),list(1,1),drop='selected')
    sub_hcst<-Subset(hcst,c('dat','var'),list(1,1),drop='selected')
    sub_fcst<-Subset(fcst,c('dat','var'),list(1,1),drop='selected')

    remove(obs,hcst,fcst)
     
    if (variable == 'prlr' || variable == 'rsds'){
       sub_obs[sub_obs < 0 ] <- 0
       sub_hcst[sub_hcst < 0 ] <- 0
    }



    if (global == TRUE){

      calibrated_fcst <-Apply(data=list(var_obs=sub_obs,
                                           var_exp=sub_hcst,
                                           var_fcst=sub_fcst),
                                 target_dims=c('sdate','member'),
                                 output_dims=c('member'),
                                 ncores=ncores,
                                 fun = Calibration_fcst)[[1]]
                                 # This function will implemented in a future release of
                                 # CSTools, from now on, is loaded from Calibration_fcst.R


      print("######### GLOBAL: FCST CALIBRATION COMPLETED ##############")
      #-------------------------------------------------------------------
      # Hindcast terciles and skill computation
      # (Only if the terciles are not loaded from external files) 
      #-------------------------------------------------------------------

      if (variable %in% accum.vars){
         na.rm <- TRUE
      } else {
         na.rm <- FALSE
      }

      if ( skill == TRUE){

        calibrated_hcst <- Hcst_Calibration(exp=sub_hcst,obs=sub_obs)

        if (variable == 'prlr' || variable == 'rsds'){
         calibrated_hcst[calibrated_hcst < 0 ] <- 0
        }
        calibrated_hcst[!is.finite(calibrated_hcst)] <- NA
  
        print("######### GLOBAL HCST CALIBRATION COMPLETED ##############")
        # Computing terciles and extremes from hindcast
  
        terciles_hcst<-Apply(calibrated_hcst,c('sdate','member'),
                  quantile,c(1/3,2/3),output_dims="bin",ncores=ncores, na.rm=na.rm)[[1]]
  
        extremes_hcst<-Apply(calibrated_hcst,c('sdate','member'),
                  quantile,c(1/10,9/10),output_dims="bin",ncores=ncores, na.rm=na.rm)[[1]]
  
        print("######### TERCILES COMPUTATION COMPLETED ##############")
        
        skill <- Compute_skill(calibrated_hcst, sub_obs, ncores=ncores)
        fRPSS <- skill$fRPSS
        BSS10 <- skill$BSS10
        BSS90 <- skill$BSS90

        print("######### SKILL COMPUTATION COMPLETED ##############")

        hcst.probs <- Compute_probs(calibrated_hcst, terciles_hcst, extremes_hcst, na.rm=na.rm, ncores=ncores)
        tercile_probs_hcst <- hcst.probs$tercile_probs_hcst
        extreme_probs_hcst <- hcst.probs$extreme_probs_hcst
        print("######### GLOBAL FCST PROBS COMPUTATION DONE ##############")


        print("######### FCST PROBS COMPUTATION DONE ##############")
  
        outfile = paste0(path.outside, variable,"-skill_month",fcst.month,".nc")
        save_skill_file(variable,
                 fRPSS,
                 BSS10,
                 BSS90,
                   fcst.sdate, 
                 lon,
                 lat,
                 outfile,
                 hcst.times)
  
        outfile = paste0(path.outside, variable,"-percentiles_month",fcst.month,".nc")
        save_terciles_file(variable,
                 terciles_hcst,
                 extremes_hcst,
                   fcst.sdate, 
                 lon,
                 lat,
                 outfile,
                 hcst.times)
  
        for (n in 1:((hcst.endyear-hcst.inityear)+1)) {
          outfile = paste0(path.outside, variable,"-prob_",hcst.sdates[n],"01.nc")
          save_probs_file(variable,
                 tercile_probs_hcst[,n,,,],
                 extreme_probs_hcst[,n,,,],
                 hcst.sdates[n],
                 lon,
                 lat,
                 outfile,
                 hcst.times[(1+((ltmax-ltmin)+1)*(n-1)):(((ltmax-ltmin)+1)*n)])
           
            outfile = paste0(path.outside, variable,"_",hcst.sdates[n],"01.nc")
            save_ensemble_file(variable,
                  calibrated_hcst[,n,,,],
                  hcst.sdates[n],
                  lon,
                  lat,
                  outfile,
                  hcst.times[(1+((ltmax-ltmin)+1)*(n-1)):(((ltmax-ltmin)+1)*n)])
           } 
       } else {
       
           fcst.month <- substr(fcst.sdate, start=5, stop=6)
           terciles.filepath <- paste0(path.outside,'/', variable, '-percentiles_month', fcst.month, 
                                        '.nc') 
           
           terciles_hcst <- NcToArray(terciles.filepath, vars_to_read=c('p33', 'p66'))
           extremes_hcst <- NcToArray(terciles.filepath, vars_to_read=c('p10', 'p90'))

           terciles_hcst <- aperm(terciles_hcst, c(1, 4, 2, 3))
           names(dim(terciles_hcst)) <- c('bin', 'time','latitude', 'longitude')
            
           extremes_hcst <- aperm(extremes_hcst, c(1, 4, 2, 3))
           names(dim(extremes_hcst)) <- c('bin', 'time','latitude', 'longitude')

           if (variable == "prlr") {
             for (month in 1:(dim(terciles_hcst)[2])){
                  hcst.times <- attr(hcst, 'Variables')$common$time
                  hcst.times <- sort(unique(sapply(as.character(hcst.times),
                      substr, 1, 10)))
                  hcst.times[which(substr(hcst.times, 9, 10) == '01')] <- as.character(as.Date(hcst.times[which(substr(hcst.times, 9, 10) == '01')], "%Y-%m-%d")-1)

                 month.sdate <- paste0(substr(hcst.times[month],1,7), "-01")
                 month.lastday <- as.integer(substr((seq(as.Date(month.sdate, "%Y-%m-%d"),
                                  length=2,by="months")-1)[2], 9, 10))
                 terciles_hcst[,month,,] <- terciles_hcst[,month,,]/(month.lastday*86400000)
                 extremes_hcst[,month,,] <- extremes_hcst[,month,,]/(month.lastday*86400000)
               }
           } else if (variable == "tasmin" || variable == "tasmax" || variable == "tas") {
              extremes_hcst <- extremes_hcst + 273
              terciles_hcst <- terciles_hcst + 273
            } else if (variable == "psl") {
              terciles_hcst <- terciles_hcst * 100
              extremes_hcst <- extremes_hcst * 100
            } else {
              warning("Unknown Variable")
            }

           
           print("######### TERCILES LOADED ##############")
  
           
       }


      #-------------------------------------------------------------------
      # Probabilities for each category
      # and extreme values
      #-------------------------------------------------------------------
   
      # Computing forecast probabilities

      fcst.probs <- Compute_probs(calibrated_fcst, terciles_hcst, extremes_hcst, na.rm=TRUE, ncores=ncores)
      tercile_probs <- fcst.probs$tercile_probs_hcst
      extreme_probs <- fcst.probs$extreme_probs_hcst
      print("######### GLOBAL FCST PROBS COMPUTATION DONE ##############")
 
      print("######### FCST PROBS COMPUTATION DONE ##############")

      #----------------------------------------------------------
      # Saving calibrated forecast like .nc
      #----------------------------------------------------------

      lon <- attr(obs, 'Variables')$dat1$longitude
      lat <- attr(obs, 'Variables')$dat1$latitude
      fcst.times <- attr(fcst, 'Variables')$common$time
      fcst.times <- sort(unique(sapply(as.character(fcst.times),
                    substr, 1, 10)))
      fcst.times[which(substr(fcst.times, 9, 10) == '01')] <- as.character(as.Date(fcst.times[which(substr(fcst.times, 9, 10) == '01')], "%Y-%m-%d")-1)

      outfile = paste0(path.outside, variable,"-prob_",fcst.sdate,"01.nc")
      save_probs_file(variable,
             tercile_probs,
             extreme_probs,
             fcst.sdate,
             lon,
             lat,
             outfile,
             fcst.times) 

      outfile = paste0(path.outside, variable,"_",fcst.sdate,"01.nc")
      save_ensemble_file(variable,
             calibrated_fcst,
             fcst.sdate,
             lon,
             lat,
             outfile,
             fcst.times) 
       
  }

  if (country == TRUE){
      print("COUNTRY-AGGREGATED CALCULATION") 
      #-------------------------------------------------------------------
      # Fcst, Hcst & Obs country-mean computation 
      #-------------------------------------------------------------------

      load(mask.path)

      sub_hcst.country <-Apply(data=list(pointdata=sub_hcst),
                                        target_dims=c('latitude','longitude'),
                                        output_dims=c('country'),
                                        mask.path=mask.path,
                                        ncores=ncores,
                                        split_factor=split_factor,
                                        fun = Country_mean)[[1]]

      sub_fcst.country <-Apply(data=list(pointdata=sub_fcst),
                                        target_dims=c('latitude','longitude'),
                                        output_dims=c('country'),
                                        mask.path=mask.path,
                                        ncores=ncores,
                                        split_factor=split_factor,
                                        fun = Country_mean)[[1]]

      sub_obs.country <-Apply(data=list(pointdata=sub_obs),
                                        target_dims=c('latitude','longitude'),
                                        output_dims=c('country'),
                                        mask.path=mask.path,
                                        ncores=ncores,
                                        split_factor=split_factor,
                                        fun = Country_mean)[[1]]

       calibrated_fcst.country <-Apply(data=list(var_obs=sub_obs.country,
                                   var_exp=sub_hcst.country,
                                   var_fcst=sub_fcst.country),
                                   target_dims=c('sdate','member'),
                                   output_dims=c('member'),
                                   ncores=ncores,
                                   split_factor=split_factor,
                                   fun = Calibration_fcst)[[1]]

      
      print("######### GLOBAL: FCST CALIBRATION COMPLETED ##############")
      #-------------------------------------------------------------------
      # Hindcast terciles and skill computation
      # (Only if the terciles are not loaded from external files) 
      #-------------------------------------------------------------------

      if (variable %in% accum.vars){
         na.rm <- TRUE
      } else {
         na.rm <- FALSE
      }

      if ( skill == TRUE){

        calibrated_hcst.country <- Hcst_Calibration(exp=sub_hcst.country,obs=sub_obs.country)

        if (variable == 'prlr' || variable == 'rsds'){
         calibrated_hcst.country[calibrated_hcst.country < 0 ] <- 0
        }
        calibrated_hcst.country[!is.finite(calibrated_hcst.country)] <- NA
  
        print("######### GLOBAL HCST CALIBRATION COMPLETED ##############")
        # Computing terciles and extremes from hindcast
  
        terciles_hcst.country <- Apply(calibrated_hcst.country,c('sdate','member'),
                  quantile,c(1/3,2/3),output_dims="bin",ncores=ncores, na.rm=na.rm, split_factor=split_factor)[[1]]

        extremes_hcst.country <- Apply(calibrated_hcst.country,c('sdate','member'),
                  quantile,c(1/10,9/10),output_dims="bin",ncores=ncores, na.rm=na.rm, split_factor=split_factor)[[1]]

  
        print("######### TERCILES COMPUTATION COMPLETED ##############")
        
        skill.country <- Compute_skill(calibrated_hcst.country, sub_obs.country, ncores=ncores, na.rm=T)
        fRPSS.country <- skill.country$fRPSS
        BSS10.country <- skill.country$BSS10
        BSS90.country <- skill.country$BSS90
   
        print("######### SKILL COMPUTATION COMPLETED ##############")
         
        hcst.probs.country <- Compute_probs(calibrated_hcst.country, terciles_hcst.country, extremes_hcst.country,
                                          na.rm = TRUE)
        tercile_probs_hcst.country <- hcst.probs.country$tercile_probs_hcst
        extreme_probs_hcst.country <- hcst.probs.country$extreme_probs_hcst
        print("######### COUNTRY FCST PROBS COMPUTATION DONE ##############")
  

        print("######### COUNTRY FCST PROBS COMPUTATION DONE ##############")
  
        outfile = paste0(path.outside,"/../",variable,"_country/", variable,"-country-skill_month",fcst.month,".nc")
        save_skill_country_file(variable,
                        fRPSS.country,
                        BSS10.country,
                        BSS90.country,
                        fcst.sdate,
                        outfile,
                        hcst.times,
                        europe.countries.iso,
                        "seasonal")
     
        outfile = paste0(path.outside,"/../",variable,"_country/", variable,"-country-percentiles_month",fcst.month,".nc")
       save_terciles_country_file(variable,
                       terciles_hcst.country,
                       extremes_hcst.country,
                       fcst.sdate,
                       outfile,
                       hcst.times,
                       europe.countries.iso,
                       "seasonal")

  
        for (n in 1:((hcst.endyear-hcst.inityear)+1)) {
            outfile = paste0(path.outside,"/../",variable,
                             "_country/", variable,"-country-prob_",hcst.sdates[n],"01.nc")
            save_probs_country_file(variable,
                                   tercile_probs_hcst.country[,n,,],
                                   extreme_probs_hcst.country[,n,,],
                                   hcst.sdates[n],
                                   outfile,
                                   hcst.times[(1+((ltmax-ltmin)+1)*(n-1)):(((ltmax-ltmin)+1)*n)],
                                   europe.countries.iso,
                                   "seasonal")
            
            outfile = paste0(path.outside,"/../",variable,
                             "_country/", variable,"-country_",hcst.sdates[n],"01.nc")
            save_ensemble_country_file(variable,
                                   aperm(calibrated_hcst.country[,n,,], c(2,1,3)),
                                   hcst.sdates[n],
                                   outfile,
                                   hcst.times[(1+((ltmax-ltmin)+1)*(n-1)):(((ltmax-ltmin)+1)*n)],
                                   europe.countries.iso,
                                   "seasonal")
            
        } 
       } else {
       
           fcst.month <- substr(fcst.sdate, start=5, stop=6)
           terciles.country.filepath <- paste0(path.outside, '/../',
                                        variable,'_country/', variable, '-country-percentiles_month', fcst.month, 
                                        '.nc') 
    
           terciles_hcst.country <- NcToArray(terciles.country.filepath, vars_to_read=c('p33', 'p66'))
           extremes_hcst.country <- NcToArray(terciles.country.filepath, vars_to_read=c('p10', 'p90'))

           terciles_hcst.country <- aperm(terciles_hcst.country, c(1, 3, 2))
           names(dim(terciles_hcst.country)) <- c('bin', 'time','country')
            
           extremes_hcst.country <- aperm(extremes_hcst.country, c(1, 3, 2))
           names(dim(extremes_hcst.country)) <- c('bin', 'time','country')

           if (variable == "prlr") {
             for (month in 1:(dim(terciles_hcst.country)[2])){
                  hcst.times <- attr(hcst, 'Variables')$common$time
                  hcst.times <- sort(unique(sapply(as.character(hcst.times),
                      substr, 1, 10)))
                  hcst.times[which(substr(hcst.times, 9, 10) == '01')] <- as.character(as.Date(hcst.times[which(substr(hcst.times, 9, 10) == '01')], "%Y-%m-%d")-1)

                 month.sdate <- paste0(substr(hcst.times[month],1,7), "-01")
                 month.lastday <- as.integer(substr((seq(as.Date(month.sdate, "%Y-%m-%d"),
                                  length=2,by="months")-1)[2], 9, 10))
                 terciles_hcst.country[,month,] <- terciles_hcst.country[,month,]/(month.lastday*86400000)
                 extremes_hcst.country[,month,] <- extremes_hcst.country[,month,]/(month.lastday*86400000)
               }
           } else if (variable == "tasmin" || variable == "tasmax" || variable == "tas") {
              extremes_hcst.country <- extremes_hcst.country + 273
              terciles_hcst.country <- terciles_hcst.country + 273
            } else if (variable == "psl") {
              terciles_hcst.country <- terciles_hcst.country * 100
              extremes_hcst.country <- extremes_hcst.country * 100
            } else {
              warning("Unknown Variable")
            }

           
           print("######### TERCILES LOADED ##############")
  
           
       }


      #-------------------------------------------------------------------
      # Probabilities for each category
      # and extreme values
      #-------------------------------------------------------------------
   
      # Computing forecast probabilities
      
      fcst.probs.country <- Compute_probs(calibrated_fcst.country, terciles_hcst.country,
                                          extremes_hcst.country, na.rm=TRUE, ncores=ncores)
      tercile_probs_fcst.country <- fcst.probs.country$tercile_probs_hcst
      extreme_probs_fcst.country <- fcst.probs.country$extreme_probs_hcst
      print("######### GLOBAL FCST PROBS COMPUTATION DONE ##############")

      print("######### FCST PROBS COMPUTATION DONE ##############")

      #----------------------------------------------------------
      # Saving calibrated forecast like .nc
      #----------------------------------------------------------

      outfile = paste0(path.outside,"/../",variable,"_country/",
               variable,"-country-prob_",fcst.sdate,"01.nc")
      save_probs_country_file(variable,
                       tercile_probs_fcst.country,
                       extreme_probs_fcst.country,
                       fcst.sdate,
                       outfile,
                       fcst.times,
                       europe.countries.iso,
                       "seasonal")


      outfile = paste0(path.outside,"/../",variable,"_country/",
                 variable,"-country_",fcst.sdate,"01.nc")
       save_ensemble_country_file(variable,
                       aperm(calibrated_fcst.country, c(2,1,3)),
                       fcst.sdate,
                       outfile,
                       fcst.times,
                       europe.countries.iso,
                       "seasonal")
       
  }  
}
